#[repr(C)]pub struct StackInfo {
pub stack_top: usize,
pub stack_bottom: usize,
}Expand description
The coroutine stack information.
Fields
stack_top: usizeThe base address of the stack. This is the highest address since stacks grow downwards on most modern architectures.
stack_bottom: usizeThe maximum limit address of the stack. This is the lowest address since stacks grow downwards on most modern architectures.