Common traits and impl.
Modules
BeanFactoryimpls.- Constants.
TimerListimpls.- Suppose a thread in a work-stealing scheduler is idle and looking for the next task to run. To find an available task, it might do the following:
Structs
Functions
- Get current linux kernel version number.
- Recommended read zone size for coroutines.
- Make the total time into slices.
- current ns time add
dur. - Get linux kernel version number.
- get the current wall clock in ns
- Get the page size of this system.